use clap::{Arg, Command, ArgMatches};

use crate::commands;
use crate::commands::credential::CredentialArgs;

pub fn create() -> Command {
    Command::new("credential")
        .about("Manage set of credentials")
        .subcommand(
            Command::new("add")
            .arg(
                Arg::new("username")
                .required(true)
                .num_args(1)
                .value_name("NAME")
                .help("The username used to connect to nextcloud"),
                )
            .arg(
                Arg::new("password")
                .required(false)
                .num_args(1)
                .value_name("PASSWORD")
                .help("The passowd used to connect to nextcloud (optional)"),
                )
            .about("Add a new set of credential")
            )
}

pub fn handler(args: &ArgMatches) {
    match args.subcommand() {
        Some(("add", add_matches)) => {
            commands::credential::credential_add(CredentialArgs {
                username: add_matches.get_one::<String>("username").unwrap().to_string(),
                password: add_matches.get_one::<String>("password").cloned(),
            });
        }
        _ => println!("Invalid or missing subcommand for 'credential'"),
    }
}
